@@ -10,6 +10,7 @@ try:
     sys.path.append(ROOT_PATH)
 
     from reqif.cli.cli_arg_parser import create_reqif_args_parser
+    from reqif.commands.anonymize.anonymize import AnonymizeCommand
     from reqif.commands.dump.dump import DumpCommand
     from reqif.commands.format.format import FormatCommand
     from reqif.commands.passthrough.passthrough import PassthroughCommand
@@ -32,6 +33,8 @@ def main():
 
     if parser.is_passthrough_command:
         PassthroughCommand.execute(parser.get_passthrough_config())
+    elif parser.is_anonymize_command:
+        AnonymizeCommand.execute(parser.get_anonymize_config())
     elif parser.is_dump_command:
         DumpCommand.execute(parser.get_dump_config())
     elif parser.is_format_command:
